@@ -2,7 +2,7 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this file,
 # You can obtain one at http://mozilla.org/MPL/2.0/.
 #
-# Copyright (c) 2014-2021, Lars Asplund lars.anders.asplund@gmail.com
+# Copyright (c) 2014-2023, Lars Asplund lars.anders.asplund@gmail.com
 
 """
 Functions to add builtin VHDL code to a project for compilation
@@ -31,7 +31,7 @@ class Builtins(object):
         self._builtins_adder = BuiltinsAdder()
 
         def add(name, deps=tuple()):
-            self._builtins_adder.add_type(name, getattr(self, "_add_%s" % name), deps)
+            self._builtins_adder.add_type(name, getattr(self, f"_add_{name!s}"), deps)
 
         add("array_util")
         add("com")
@@ -47,10 +47,7 @@ class Builtins(object):
         """
         Add files with naming convention to indicate which standard is supported
         """
-        supports_context = (
-            self._simulator_class.supports_vhdl_contexts()
-            and self._vhdl_standard.supports_context
-        )
+        supports_context = self._simulator_class.supports_vhdl_contexts() and self._vhdl_standard.supports_context
 
         for file_name in get_checked_file_names_from_globs(pattern, allow_empty):
             base_file_name = Path(file_name).name
@@ -60,6 +57,8 @@ class Builtins(object):
                 standard_name = str(standard)
                 if standard_name + "p" in base_file_name:
                     standards.update(standard.and_later)
+                elif standard_name + "m" in base_file_name:
+                    standards.update(standard.and_earlier)
                 elif standard_name in base_file_name:
                     standards.add(standard)
 
@@ -85,17 +84,8 @@ class Builtins(object):
 
         for key in ["string", "integer_vector"]:
             self._add_files(
-                pattern=str(
-                    VHDL_PATH
-                    / "data_types"
-                    / "src"
-                    / "api"
-                    / ("external_%s_pkg.vhd" % key)
-                )
-                if external is None
-                or key not in external
-                or not external[key]
-                or external[key] is True
+                pattern=str(VHDL_PATH / "data_types" / "src" / "api" / f"external_{key!s}_pkg.vhd")
+                if external is None or key not in external or not external[key] or external[key] is True
                 else external[key],
                 allow_empty=False,
             )
@@ -108,8 +98,7 @@ class Builtins(object):
             raise RuntimeError("Array util only supports vhdl 2008 and later")
 
         arr_deprecation_note = (
-            "'array_t' is deprecated and it will removed in future releases;"
-            "use 'integer_array_t' instead"
+            "'array_t' is deprecated and it will removed in future releases; use 'integer_array_t' instead"
         )
         warn(arr_deprecation_note, Warning)
 
@@ -129,9 +118,7 @@ class Builtins(object):
         Add com library
         """
         if not self._vhdl_standard >= VHDL.STD_2008:
-            raise RuntimeError(
-                "Communication package only supports vhdl 2008 and later"
-            )
+            raise RuntimeError("Communication package only supports vhdl 2008 and later")
 
         self._add_files(VHDL_PATH / "com" / "src" / "*.vhd")
 
@@ -140,9 +127,7 @@ class Builtins(object):
         Add verification component library
         """
         if not self._vhdl_standard >= VHDL.STD_2008:
-            raise RuntimeError(
-                "Verification component library only supports vhdl 2008 and later"
-            )
+            raise RuntimeError("Verification component library only supports vhdl 2008 and later")
         self._add_files(VHDL_PATH / "verification_components" / "src" / "*.vhd")
 
     def _add_osvvm(self):
@@ -157,9 +142,7 @@ class Builtins(object):
             library = self._vunit_obj.add_library(library_name)
 
         simulator_coverage_api = self._simulator_class.get_osvvm_coverage_api()
-        supports_vhdl_package_generics = (
-            self._simulator_class.supports_vhdl_package_generics()
-        )
+        supports_vhdl_package_generics = self._simulator_class.supports_vhdl_package_generics()
 
         if not osvvm_is_installed():
             raise RuntimeError(
@@ -177,12 +160,8 @@ in your VUnit Git repository? You have to do this first if installing using setu
             if (bname == "AlertLogPkg_body_BVUL.vhd") or ("2019" in bname):
                 continue
 
-            if (
-                (simulator_coverage_api != "rivierapro")
-                and (bname == "VendorCovApiPkg_Aldec.vhd")
-            ) or (
-                (simulator_coverage_api == "rivierapro")
-                and (bname == "VendorCovApiPkg.vhd")
+            if ((simulator_coverage_api != "rivierapro") and (bname == "VendorCovApiPkg_Aldec.vhd")) or (
+                (simulator_coverage_api == "rivierapro") and (bname == "VendorCovApiPkg.vhd")
             ):
                 continue
 
@@ -293,7 +272,7 @@ class BuiltinsAdder(object):
         old_args = self._already_added[name]
         if args != old_args:
             raise RuntimeError(
-                "Optional builtin %r added with arguments %r has already been added with arguments %r"
-                % (name, args, old_args)
+                f"Optional builtin {name!r} added with arguments {args!r} "
+                f"has already been added with arguments {old_args!r}"
             )
         return True
