@@ -2,7 +2,7 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this file,
 # You can obtain one at http://mozilla.org/MPL/2.0/.
 #
-# Copyright (c) 2014-2021, Lars Asplund lars.anders.asplund@gmail.com
+# Copyright (c) 2014-2023, Lars Asplund lars.anders.asplund@gmail.com
 
 """
 Module containing the CodecVHDLArrayType class.
@@ -28,31 +28,17 @@ class CodecVHDLArrayType(VHDLArrayType):
             and self.range2.attribute is None
             and self.range2.range_type is None
         )
-        is_constrained = (
-            self.range1.range_type is None and self.range2.range_type is None
-        )
+        is_constrained = self.range1.range_type is None and self.range2.range_type is None
 
         declarations += template.codec_declarations.substitute(type=self.identifier)
         declarations += template.to_string_declarations.substitute(type=self.identifier)
         if is_constrained:
             if has_one_dimension:
-                definitions += template.constrained_1d_array_definition.substitute(
-                    type=self.identifier
-                )
-                definitions += (
-                    template.constrained_1d_array_to_string_definition.substitute(
-                        type=self.identifier
-                    )
-                )
+                definitions += template.constrained_1d_array_definition.substitute(type=self.identifier)
+                definitions += template.constrained_1d_array_to_string_definition.substitute(type=self.identifier)
             else:
-                definitions += template.constrained_2d_array_definition.substitute(
-                    type=self.identifier
-                )
-                definitions += (
-                    template.constrained_2d_array_to_string_definition.substitute(
-                        type=self.identifier
-                    )
-                )
+                definitions += template.constrained_2d_array_definition.substitute(type=self.identifier)
+                definitions += template.constrained_2d_array_to_string_definition.substitute(type=self.identifier)
         else:
             if has_one_dimension:
                 init_value = ""
@@ -61,10 +47,8 @@ class CodecVHDLArrayType(VHDLArrayType):
                     init_value=init_value,
                     range_type=self.range1.range_type,
                 )
-                definitions += (
-                    template.unconstrained_1d_array_to_string_definition.substitute(
-                        array_type=self.identifier, range_type=self.range1.range_type
-                    )
+                definitions += template.unconstrained_1d_array_to_string_definition.substitute(
+                    array_type=self.identifier, range_type=self.range1.range_type
                 )
             else:
                 definitions += template.unconstrained_2d_array_definition.substitute(
@@ -72,12 +56,10 @@ class CodecVHDLArrayType(VHDLArrayType):
                     range_type1=self.range1.range_type,
                     range_type2=self.range2.range_type,
                 )
-                definitions += (
-                    template.unconstrained_2d_array_to_string_definition.substitute(
-                        array_type=self.identifier,
-                        range_type1=self.range1.range_type,
-                        range_type2=self.range2.range_type,
-                    )
+                definitions += template.unconstrained_2d_array_to_string_definition.substitute(
+                    array_type=self.identifier,
+                    range_type1=self.range1.range_type,
+                    range_type2=self.range2.range_type,
                 )
 
         return declarations, definitions
