@@ -2,7 +2,7 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this file,
 # You can obtain one at http://mozilla.org/MPL/2.0/.
 #
-# Copyright (c) 2014-2021, Lars Asplund lars.anders.asplund@gmail.com
+# Copyright (c) 2014-2023, Lars Asplund lars.anders.asplund@gmail.com
 
 # pylint: disable=too-many-lines
 
@@ -43,9 +43,7 @@ from .library import Library
 from .results import Results
 
 
-class VUnit(  # pylint: disable=too-many-instance-attributes, too-many-public-methods
-    object
-):
+class VUnit(object):  # pylint: disable=too-many-instance-attributes, too-many-public-methods
     """
     The public interface of VUnit
 
@@ -81,9 +79,7 @@ class VUnit(  # pylint: disable=too-many-instance-attributes, too-many-public-me
 
         """
         args = VUnitCLI().parse_args(argv=argv)
-        return cls.from_args(
-            args, compile_builtins=compile_builtins, vhdl_standard=vhdl_standard
-        )
+        return cls.from_args(args, compile_builtins=compile_builtins, vhdl_standard=vhdl_standard)
 
     @classmethod
     def from_args(
@@ -147,9 +143,7 @@ class VUnit(  # pylint: disable=too-many-instance-attributes, too-many-public-me
             self._simulator_output_path = str(Path(self._output_path) / "none")
         else:
             simulator_class = self._simulator_class
-            self._simulator_output_path = str(
-                Path(self._output_path) / simulator_class.name
-            )
+            self._simulator_output_path = str(Path(self._output_path) / simulator_class.name)
 
         self._create_output_path(args.clean)
 
@@ -198,9 +192,7 @@ class VUnit(  # pylint: disable=too-many-instance-attributes, too-many-public-me
         Configure logging based on log_level string
         """
         level = getattr(logging, log_level.upper())
-        logging.basicConfig(
-            filename=None, format="%(levelname)7s - %(message)s", level=level
-        )
+        logging.basicConfig(filename=None, format="%(levelname)7s - %(message)s", level=level)
 
     def _which_vhdl_standard(self, vhdl_standard: Optional[str]) -> VHDLStandard:
         """
@@ -212,9 +204,7 @@ class VUnit(  # pylint: disable=too-many-instance-attributes, too-many-public-me
 
         return VHDL.standard(vhdl_standard)
 
-    def add_external_library(
-        self, library_name, path: Union[str, Path], vhdl_standard: Optional[str] = None
-    ):
+    def add_external_library(self, library_name, path: Union[str, Path], vhdl_standard: Optional[str] = None):
         """
         Add an externally compiled library as a black-box
 
@@ -240,9 +230,7 @@ class VUnit(  # pylint: disable=too-many-instance-attributes, too-many-public-me
         )
         return self.library(library_name)
 
-    def add_source_files_from_csv(
-        self, project_csv_path: Union[str, Path], vhdl_standard: Optional[str] = None
-    ):
+    def add_source_files_from_csv(self, project_csv_path: Union[str, Path], vhdl_standard: Optional[str] = None):
         """
         Add a project configuration, mapping all the libraries and files
 
@@ -256,28 +244,22 @@ class VUnit(  # pylint: disable=too-many-instance-attributes, too-many-public-me
 
         """
         libs: Set[str] = set()
-        files = SourceFileList(list())
+        files = SourceFileList([])
 
         ppath = Path(project_csv_path)
 
-        with ppath.open() as csv_path_file:
+        with ppath.open("r", encoding="utf-8") as csv_path_file:
             for row in csv.reader(csv_path_file):
                 if len(row) == 2:
                     lib_name = row[0].strip()
                     no_normalized_file = row[1].strip()
                     file_name_ = str((ppath.parent / no_normalized_file).resolve())
-                    lib = (
-                        self.library(lib_name)
-                        if lib_name in libs
-                        else self.add_library(lib_name)
-                    )
+                    lib = self.library(lib_name) if lib_name in libs else self.add_library(lib_name)
                     libs.add(lib_name)
                     file_ = lib.add_source_file(file_name_, vhdl_standard=vhdl_standard)
                     files.append(file_)
                 elif len(row) > 2:
-                    LOGGER.error(
-                        "More than one library and one file in csv description"
-                    )
+                    LOGGER.error("More than one library and one file in csv description")
         return files
 
     def add_library(
@@ -309,10 +291,7 @@ class VUnit(  # pylint: disable=too-many-instance-attributes, too-many-public-me
         if not self._project.has_library(library_name):
             self._project.add_library(library_name, str(path.resolve()), standard)
         elif not allow_duplicate:
-            raise ValueError(
-                "Library %s already added. Use allow_duplicate to ignore this error."
-                % library_name
-            )
+            raise ValueError(f"Library {library_name!s} already added. Use allow_duplicate to ignore this error.")
         return self.library(library_name)
 
     def library(self, library_name: str):
@@ -344,9 +323,7 @@ class VUnit(  # pylint: disable=too-many-instance-attributes, too-many-public-me
            Only affects test benches added *before* the attribute is set.
         """
         test_benches = self._test_bench_list.get_test_benches()
-        for test_bench in check_not_empty(
-            test_benches, allow_empty, "No test benches found"
-        ):
+        for test_bench in check_not_empty(test_benches, allow_empty, "No test benches found"):
             test_bench.set_attribute(name, value)
 
     def set_generic(self, name: str, value: str, allow_empty: Optional[bool] = False):
@@ -367,9 +344,7 @@ class VUnit(  # pylint: disable=too-many-instance-attributes, too-many-public-me
            Only affects test benches added *before* the generic is set.
         """
         test_benches = self._test_bench_list.get_test_benches()
-        for test_bench in check_not_empty(
-            test_benches, allow_empty, "No test benches found"
-        ):
+        for test_bench in check_not_empty(test_benches, allow_empty, "No test benches found"):
             test_bench.set_generic(name.lower(), value)
 
     def set_parameter(self, name: str, value: str, allow_empty: Optional[bool] = False):
@@ -390,9 +365,7 @@ class VUnit(  # pylint: disable=too-many-instance-attributes, too-many-public-me
            Only affects test benches added *before* the parameter is set.
         """
         test_benches = self._test_bench_list.get_test_benches()
-        for test_bench in check_not_empty(
-            test_benches, allow_empty, "No test benches found"
-        ):
+        for test_bench in check_not_empty(test_benches, allow_empty, "No test benches found"):
             test_bench.set_generic(name, value)
 
     def set_sim_option(
@@ -420,14 +393,10 @@ class VUnit(  # pylint: disable=too-many-instance-attributes, too-many-public-me
            Only affects test benches added *before* the option is set.
         """
         test_benches = self._test_bench_list.get_test_benches()
-        for test_bench in check_not_empty(
-            test_benches, allow_empty, "No test benches found"
-        ):
+        for test_bench in check_not_empty(test_benches, allow_empty, "No test benches found"):
             test_bench.set_sim_option(name, value, overwrite)
 
-    def set_compile_option(
-        self, name: str, value: str, allow_empty: Optional[bool] = False
-    ):
+    def set_compile_option(self, name: str, value: str, allow_empty: Optional[bool] = False):
         """
         Set compile option of all files
 
@@ -446,14 +415,10 @@ class VUnit(  # pylint: disable=too-many-instance-attributes, too-many-public-me
            Only affects files added *before* the option is set.
         """
         source_files = self._project.get_source_files_in_order()
-        for source_file in check_not_empty(
-            source_files, allow_empty, "No source files found"
-        ):
+        for source_file in check_not_empty(source_files, allow_empty, "No source files found"):
             source_file.set_compile_option(name, value)
 
-    def add_compile_option(
-        self, name: str, value: str, allow_empty: Optional[bool] = False
-    ):
+    def add_compile_option(self, name: str, value: str, allow_empty: Optional[bool] = False):
         """
         Add compile option to all files
 
@@ -465,14 +430,10 @@ class VUnit(  # pylint: disable=too-many-instance-attributes, too-many-public-me
            Only affects files added *before* the option is set.
         """
         source_files = self._project.get_source_files_in_order()
-        for source_file in check_not_empty(
-            source_files, allow_empty, "No source files found"
-        ):
+        for source_file in check_not_empty(source_files, allow_empty, "No source files found"):
             source_file.add_compile_option(name, value)
 
-    def get_source_file(
-        self, file_name: Union[str, Path], library_name: Optional[str] = None
-    ):
+    def get_source_file(self, file_name: Union[str, Path], library_name: Optional[str] = None):
         """
         Get a source file
 
@@ -485,17 +446,12 @@ class VUnit(  # pylint: disable=too-many-instance-attributes, too-many-public-me
 
         files = self.get_source_files(fstr, library_name, allow_empty=True)
         if len(files) > 1:
-            raise ValueError(
-                "Found file named '%s' in multiple-libraries, "
-                "add explicit library_name." % fstr
-            )
+            raise ValueError(f"Found file named '{fstr!s}' in multiple-libraries, " "add explicit library_name.")
         if not files:
             if library_name is None:
-                raise ValueError("Found no file named '%s'" % fstr)
+                raise ValueError(f"Found no file named '{fstr!s}'")
 
-            raise ValueError(
-                "Found no file named '%s' in library '%s'" % (fstr, library_name)
-            )
+            raise ValueError(f"Found no file named '{fstr!s}' in library '{library_name!s}'")
         return files[0]
 
     def get_source_files(
@@ -529,10 +485,8 @@ class VUnit(  # pylint: disable=too-many-instance-attributes, too-many-public-me
         check_not_empty(
             results,
             allow_empty,
-            ("Pattern %r did not match any file" % pattern)
-            + (
-                ("within library %s" % library_name) if library_name is not None else ""
-            ),
+            f"Pattern {pattern!r} did not match any file"
+            + (f"within library {library_name!s}" if library_name is not None else ""),
         )
 
         return SourceFileList(results)
@@ -624,9 +578,7 @@ class VUnit(  # pylint: disable=too-many-instance-attributes, too-many-public-me
             file_type=file_type,
         )
 
-    def _preprocess(
-        self, library_name: str, file_name: Union[str, Path], preprocessors
-    ):
+    def _preprocess(self, library_name: str, file_name: Union[str, Path], preprocessors):
         """
         Preprocess file_name within library_name using explicit preprocessors
         if preprocessors is None then use implicit globally defined processors
@@ -660,13 +612,9 @@ class VUnit(  # pylint: disable=too-many-instance-attributes, too-many-public-me
 
             idx = 1
             while ostools.file_exists(pp_file_name):
-                LOGGER.debug(
-                    "Preprocessed file exists '%s', adding prefix", pp_file_name
-                )
+                LOGGER.debug("Preprocessed file exists '%s', adding prefix", pp_file_name)
                 pp_file_name = str(
-                    Path(self._preprocessed_path)
-                    / library_name
-                    / ("%i_%s" % (idx, fname)),
+                    Path(self._preprocessed_path) / library_name / f"{idx}_{fname!s}",
                 )
                 idx += 1
 
@@ -679,9 +627,7 @@ class VUnit(  # pylint: disable=too-many-instance-attributes, too-many-public-me
         """
         self._external_preprocessors.append(preprocessor)
 
-    def enable_location_preprocessing(
-        self, additional_subprograms=None, exclude_subprograms=None
-    ):
+    def enable_location_preprocessing(self, additional_subprograms=None, exclude_subprograms=None):
         """
         Inserts file name and line number information into VUnit check and log subprograms calls. Custom
         subprograms can also be added. Must be called before adding any files.
@@ -746,9 +692,7 @@ avoid location preprocessing of other functions sharing name with a VUnit log or
         Create the test cases
         """
         self._test_bench_list.warn_when_empty()
-        test_list = self._test_bench_list.create_tests(
-            simulator_if, self._args.elaborate
-        )
+        test_list = self._test_bench_list.create_tests(simulator_if, self._args.elaborate)
         test_list.keep_matches(self._test_filter)
         return test_list
 
@@ -788,9 +732,7 @@ avoid location preprocessing of other functions sharing name with a VUnit log or
         if not Path(self._simulator_output_path).exists():
             os.makedirs(self._simulator_output_path)
 
-        return self._simulator_class.from_args(
-            args=self._args, output_path=self._simulator_output_path
-        )
+        return self._simulator_class.from_args(args=self._args, output_path=self._simulator_output_path)
 
     def _main_run(self, post_run):
         """
@@ -833,12 +775,10 @@ avoid location preprocessing of other functions sharing name with a VUnit log or
         test_list = self._create_tests(simulator_if=None)
         for test_name in test_list.test_names:
             print(test_name)
-        print("Listed %i tests" % test_list.num_tests)
+        print(f"Listed {test_list.num_tests} tests")
         return True
 
-    def _main_export_json(
-        self, json_file_name: Union[str, Path]
-    ):  # pylint: disable=too-many-locals
+    def _main_export_json(self, json_file_name: Union[str, Path]):  # pylint: disable=too-many-locals
         """
         Main function when exporting to JSON
         """
@@ -888,7 +828,7 @@ avoid location preprocessing of other functions sharing name with a VUnit log or
             tests=tests,
         )
 
-        with Path(json_file_name).open("w") as fptr:
+        with Path(json_file_name).open("w", encoding="utf-8") as fptr:
             json.dump(json_data, fptr, sort_keys=True, indent=4, separators=(",", ": "))
 
         return True
@@ -899,8 +839,8 @@ avoid location preprocessing of other functions sharing name with a VUnit log or
         """
         files = self.get_compile_order()
         for source_file in files:
-            print("%s, %s" % (source_file.library.name, source_file.name))
-        print("Listed %i files" % len(files))
+            print(f"{source_file.library.name!s}, {source_file.name!s}")
+        print(f"Listed {len(files)} files")
         return True
 
     def _main_compile_only(self):
@@ -958,9 +898,7 @@ avoid location preprocessing of other functions sharing name with a VUnit log or
         test_list = self._create_tests(simulator_if)
         tb_file_names = {test_suite.file_name for test_suite in test_list}
         return [
-            self.get_source_file(  # pylint: disable=protected-access
-                file_name
-            )._source_file
+            self.get_source_file(file_name)._source_file  # pylint: disable=protected-access
             for file_name in tb_file_names
         ]
 
@@ -1055,17 +993,9 @@ avoid location preprocessing of other functions sharing name with a VUnit log or
         if source_files is None:
             source_files = self.get_source_files(allow_empty=True)
 
-        target_files = [
-            source_file._source_file  # pylint: disable=protected-access
-            for source_file in source_files
-        ]
+        target_files = [source_file._source_file for source_file in source_files]  # pylint: disable=protected-access
         source_files = self._project.get_dependencies_in_compile_order(target_files)
-        return SourceFileList(
-            [
-                SourceFile(source_file, self._project, self)
-                for source_file in source_files
-            ]
-        )
+        return SourceFileList([SourceFile(source_file, self._project, self) for source_file in source_files])
 
     def get_implementation_subset(self, source_files):
         """
@@ -1076,19 +1006,9 @@ avoid location preprocessing of other functions sharing name with a VUnit log or
         :param source_files: A list of :class:`.SourceFile` objects
         :returns: A list of :class:`.SourceFile` objects which is the implementation subset.
         """
-        target_files = [
-            source_file._source_file  # pylint: disable=protected-access
-            for source_file in source_files
-        ]
-        source_files = self._project.get_dependencies_in_compile_order(
-            target_files, implementation_dependencies=True
-        )
-        return SourceFileList(
-            [
-                SourceFile(source_file, self._project, self)
-                for source_file in source_files
-            ]
-        )
+        target_files = [source_file._source_file for source_file in source_files]  # pylint: disable=protected-access
+        source_files = self._project.get_dependencies_in_compile_order(target_files, implementation_dependencies=True)
+        return SourceFileList([SourceFile(source_file, self._project, self) for source_file in source_files])
 
     def get_simulator_name(self):
         """
