@@ -2,105 +2,114 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this file,
 # You can obtain one at http://mozilla.org/MPL/2.0/.
 #
-# Copyright (c) 2014-2021, Lars Asplund lars.anders.asplund@gmail.com
+# Copyright (c) 2014-2023, Lars Asplund lars.anders.asplund@gmail.com
 
 from pathlib import Path
 from string import Template
 
 api_template = """  procedure check_equal(
-    constant got       : in $got_type;
-    constant expected  : in $expected_type;
-    constant msg       : in string      := check_result_tag;
-    constant level     : in log_level_t := null_log_level;
-    constant line_num  : in natural     := 0;
-    constant file_name : in string      := "");
+    constant got         : in $got_type;
+    constant expected    : in $expected_type;
+    constant msg         : in string      := check_result_tag;
+    constant level       : in log_level_t := null_log_level;
+    constant path_offset : in natural     := 0;
+    constant line_num    : in natural     := 0;
+    constant file_name   : in string      := "");
 
   procedure check_equal(
-    variable pass      : out boolean;
-    constant got       : in $got_type;
-    constant expected  : in $expected_type;
-    constant msg       : in string      := check_result_tag;
-    constant level     : in log_level_t := null_log_level;
-    constant line_num  : in natural     := 0;
-    constant file_name : in string      := "");
+    variable pass        : out boolean;
+    constant got         : in $got_type;
+    constant expected    : in $expected_type;
+    constant msg         : in string      := check_result_tag;
+    constant level       : in log_level_t := null_log_level;
+    constant path_offset : in natural     := 0;
+    constant line_num    : in natural     := 0;
+    constant file_name   : in string      := "");
 
   procedure check_equal(
-    constant checker   : in checker_t;
-    variable pass      : out boolean;
-    constant got       : in $got_type;
-    constant expected  : in $expected_type;
-    constant msg       : in string      := check_result_tag;
-    constant level     : in log_level_t := null_log_level;
-    constant line_num  : in natural     := 0;
-    constant file_name : in string      := "");
+    constant checker     : in checker_t;
+    variable pass        : out boolean;
+    constant got         : in $got_type;
+    constant expected    : in $expected_type;
+    constant msg         : in string      := check_result_tag;
+    constant level       : in log_level_t := null_log_level;
+    constant path_offset : in natural     := 0;
+    constant line_num    : in natural     := 0;
+    constant file_name   : in string      := "");
 
   procedure check_equal(
-    constant checker   : in checker_t;
-    constant got       : in $got_type;
-    constant expected  : in $expected_type;
-    constant msg       : in string      := check_result_tag;
-    constant level     : in log_level_t := null_log_level;
-    constant line_num  : in natural     := 0;
-    constant file_name : in string      := "");
+    constant checker     : in checker_t;
+    constant got         : in $got_type;
+    constant expected    : in $expected_type;
+    constant msg         : in string      := check_result_tag;
+    constant level       : in log_level_t := null_log_level;
+    constant path_offset : in natural     := 0;
+    constant line_num    : in natural     := 0;
+    constant file_name   : in string      := "");
 
   impure function check_equal(
-    constant got       : in $got_type;
-    constant expected  : in $expected_type;
-    constant msg       : in string      := check_result_tag;
-    constant level     : in log_level_t := null_log_level;
-    constant line_num  : in natural     := 0;
-    constant file_name : in string      := "")
+    constant got         : in $got_type;
+    constant expected    : in $expected_type;
+    constant msg         : in string      := check_result_tag;
+    constant level       : in log_level_t := null_log_level;
+    constant path_offset : in natural     := 0;
+    constant line_num    : in natural     := 0;
+    constant file_name   : in string      := "")
     return boolean;
 
   impure function check_equal(
-    constant checker   : in checker_t;
-    constant got       : in $got_type;
-    constant expected  : in $expected_type;
-    constant msg       : in string      := check_result_tag;
-    constant level     : in log_level_t := null_log_level;
-    constant line_num  : in natural     := 0;
-    constant file_name : in string      := "")
+    constant checker     : in checker_t;
+    constant got         : in $got_type;
+    constant expected    : in $expected_type;
+    constant msg         : in string      := check_result_tag;
+    constant level       : in log_level_t := null_log_level;
+    constant path_offset : in natural     := 0;
+    constant line_num    : in natural     := 0;
+    constant file_name   : in string      := "")
     return boolean;
 
 """
 
 impl_template = """  procedure check_equal(
-    constant got       : in $got_type;
-    constant expected  : in $expected_type;
-    constant msg       : in string      := check_result_tag;
-    constant level     : in log_level_t := null_log_level;
-    constant line_num  : in natural     := 0;
-    constant file_name : in string      := "") is
+    constant got         : in $got_type;
+    constant expected    : in $expected_type;
+    constant msg         : in string      := check_result_tag;
+    constant level       : in log_level_t := null_log_level;
+    constant path_offset : in natural     := 0;
+    constant line_num    : in natural     := 0;
+    constant file_name   : in string      := "") is
     variable pass : boolean;
   begin
     -- pragma translate_off
-    check_equal(default_checker, pass, got, expected, msg, level, line_num, file_name);
+    check_equal(default_checker, pass, got, expected, msg, level, path_offset + 1, line_num, file_name);
     -- pragma translate_on
   end;
 
   procedure check_equal(
-    variable pass      : out boolean;
-    constant got       : in $got_type;
-    constant expected  : in $expected_type;
-    constant msg       : in string      := check_result_tag;
-    constant level     : in log_level_t := null_log_level;
-    constant line_num  : in natural     := 0;
-    constant file_name : in string      := "") is
+    variable pass        : out boolean;
+    constant got         : in $got_type;
+    constant expected    : in $expected_type;
+    constant msg         : in string      := check_result_tag;
+    constant level       : in log_level_t := null_log_level;
+    constant path_offset : in natural     := 0;
+    constant line_num    : in natural     := 0;
+    constant file_name   : in string      := "") is
   begin
     -- pragma translate_off
-    check_equal(default_checker, pass, got, expected, msg, level, line_num, file_name);
+    check_equal(default_checker, pass, got, expected, msg, level, path_offset + 1, line_num, file_name);
     -- pragma translate_on
   end;
 
   procedure check_equal(
-    constant checker   : in checker_t;
-    variable pass      : out boolean;
-    constant got       : in $got_type;
-    constant expected  : in $expected_type;
-    constant msg       : in string      := check_result_tag;
-    constant level     : in log_level_t := null_log_level;
-    constant line_num  : in natural     := 0;
-    constant file_name : in string      := "") is
+    constant checker     : in checker_t;
+    variable pass        : out boolean;
+    constant got         : in $got_type;
+    constant expected    : in $expected_type;
+    constant msg         : in string      := check_result_tag;
+    constant level       : in log_level_t := null_log_level;
+    constant path_offset : in natural     := 0;
+    constant line_num    : in natural     := 0;
+    constant file_name   : in string      := "") is
   begin
     -- pragma translate_off
     if got = expected then
@@ -111,7 +120,7 @@ impl_template = """  procedure check_equal(
           std_msg(
             "Equality check passed", msg,
             "Got " & $got_str & "."),
-          line_num, file_name);
+          path_offset + 1, line_num, file_name);
       else
         passing_check(checker);
       end if;
@@ -123,55 +132,58 @@ impl_template = """  procedure check_equal(
           "Equality check failed", msg,
           "Got " & $got_str & ". " &
           "Expected " & $expected_str & "."),
-        level, line_num, file_name);
+        level, path_offset + 1, line_num, file_name);
     end if;
     -- pragma translate_on
   end;
 
   procedure check_equal(
-    constant checker   : in checker_t;
-    constant got       : in $got_type;
-    constant expected  : in $expected_type;
-    constant msg       : in string      := check_result_tag;
-    constant level     : in log_level_t := null_log_level;
-    constant line_num  : in natural     := 0;
-    constant file_name : in string      := "") is
+    constant checker     : in checker_t;
+    constant got         : in $got_type;
+    constant expected    : in $expected_type;
+    constant msg         : in string      := check_result_tag;
+    constant level       : in log_level_t := null_log_level;
+    constant path_offset : in natural     := 0;
+    constant line_num    : in natural     := 0;
+    constant file_name   : in string      := "") is
     variable pass : boolean;
   begin
     -- pragma translate_off
-    check_equal(checker, pass, got, expected, msg, level, line_num, file_name);
+    check_equal(checker, pass, got, expected, msg, level, path_offset + 1, line_num, file_name);
     -- pragma translate_on
   end;
 
   impure function check_equal(
-    constant got       : in $got_type;
-    constant expected  : in $expected_type;
-    constant msg       : in string      := check_result_tag;
-    constant level     : in log_level_t := null_log_level;
-    constant line_num  : in natural     := 0;
-    constant file_name : in string      := "")
+    constant got         : in $got_type;
+    constant expected    : in $expected_type;
+    constant msg         : in string      := check_result_tag;
+    constant level       : in log_level_t := null_log_level;
+    constant path_offset : in natural     := 0;
+    constant line_num    : in natural     := 0;
+    constant file_name   : in string      := "")
     return boolean is
     variable pass : boolean;
   begin
     -- pragma translate_off
-    check_equal(default_checker, pass, got, expected, msg, level, line_num, file_name);
+    check_equal(default_checker, pass, got, expected, msg, level, path_offset + 1, line_num, file_name);
     -- pragma translate_on
     return pass;
   end;
 
   impure function check_equal(
-    constant checker   : in checker_t;
-    constant got       : in $got_type;
-    constant expected  : in $expected_type;
-    constant msg       : in string      := check_result_tag;
-    constant level     : in log_level_t := null_log_level;
-    constant line_num  : in natural     := 0;
-    constant file_name : in string      := "")
+    constant checker     : in checker_t;
+    constant got         : in $got_type;
+    constant expected    : in $expected_type;
+    constant msg         : in string      := check_result_tag;
+    constant level       : in log_level_t := null_log_level;
+    constant path_offset : in natural     := 0;
+    constant line_num    : in natural     := 0;
+    constant file_name   : in string      := "")
     return boolean is
     variable pass : boolean;
   begin
     -- pragma translate_off
-    check_equal(checker, pass, got, expected, msg, level, line_num, file_name);
+    check_equal(checker, pass, got, expected, msg, level, path_offset + 1, line_num, file_name);
     -- pragma translate_on
     return pass;
   end;
@@ -546,11 +558,7 @@ def dual_format(base_type, got_or_expected):
     expected_or_got = "expected" if got_or_expected == "got" else "got"
 
     if base_type in ["unsigned", "signed", "std_logic_vector"]:
-        return (
-            'to_nibble_string(%s) & " (" & ' % got_or_expected
-            + "to_integer_string(%s) & " % got_or_expected
-            + '")"'
-        )
+        return 'to_nibble_string(%s) & " (" & ' % got_or_expected + "to_integer_string(%s) & " % got_or_expected + '")"'
 
     return (
         'to_string(%s) & " (" & ' % got_or_expected
@@ -568,9 +576,7 @@ def generate_impl():
     impl = ""
     for c in combinations:
         t = Template(impl_template)
-        if (c[0] in ["unsigned", "signed", "std_logic_vector"]) or (
-            c[1] in ["unsigned", "signed", "std_logic_vector"]
-        ):
+        if (c[0] in ["unsigned", "signed", "std_logic_vector"]) or (c[1] in ["unsigned", "signed", "std_logic_vector"]):
             got_str = dual_format(c[0], "got")
             expected_str = dual_format(c[1], "expected")
         else:
@@ -593,7 +599,7 @@ def generate_test():
 -- License, v. 2.0. If a copy of the MPL was not distributed with this file,
 -- You can obtain one at http://mozilla.org/MPL/2.0/.
 --
--- Copyright (c) 2014-2021, Lars Asplund lars.anders.asplund@gmail.com
+-- Copyright (c) 2014-2023, Lars Asplund lars.anders.asplund@gmail.com
 
 library ieee;
 use ieee.std_logic_1164.all;
@@ -749,7 +755,10 @@ def replace_region(region_name, file_name, new_contents):
     result = ""
     inside_region = False
 
-    with open(file_name, "rb") as fptr:
+    if not isinstance(file_name, Path):
+        file_name = Path(file_name)
+
+    with file_name.open("rb") as fptr:
         contents = fptr.read().decode()
 
     previous_line = ""
@@ -766,9 +775,7 @@ def replace_region(region_name, file_name, new_contents):
         if not inside_region:
             result += line + "\n"
 
-        if previous_line.startswith("  -- %s" % region_name) and line.startswith(
-            "  ----------"
-        ):
+        if previous_line.startswith("  -- %s" % region_name) and line.startswith("  ----------"):
             assert not found_region
             inside_region = True
 
@@ -776,20 +783,22 @@ def replace_region(region_name, file_name, new_contents):
 
     assert found_region
 
-    with open(file_name, "wb") as fptr:
+    with file_name.open("wb") as fptr:
         fptr.write(result.encode())
 
 
 def main():
-    check_api_file_name = str(Path(__file__).parent.parent / "src" / "check_api.vhd")
-    replace_region("check_equal", check_api_file_name, generate_api())
-
-    check_file_name = str(Path(__file__).parent.parent / "src" / "check.vhd")
-    replace_region("check_equal", check_file_name, generate_impl())
-
-    with (Path(__file__).parent.parent / "test" / "tb_check_equal.vhd").open(
-        "wb"
-    ) as fptr:
+    replace_region(
+        "check_equal",
+        str(Path(__file__).parent.parent / "src" / "check_api.vhd"),
+        generate_api(),
+    )
+    replace_region(
+        "check_equal",
+        str(Path(__file__).parent.parent / "src" / "check.vhd"),
+        generate_impl(),
+    )
+    with (Path(__file__).parent.parent / "test" / "tb_check_equal.vhd").open("wb") as fptr:
         fptr.write(generate_test().encode())
 
 
